.. Copyright © SixtyFPS GmbH <info@slint.dev>
.. SPDX-License-Identifier: MIT

Syntax
======

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Reference

   comments.md
   identifiers.md
   types.md
   properties.md
   expressions.md
   functions.md
   callbacks.md
   statements.md
   repetitions.md
   conditions.md
   animations.md
   states.md
   globals.md
   modules.md
   legacy_syntax.md
